#include <qapplication.h>
#include <qmessagebox.h>
#include <qinputdialog.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qtoolbar.h>
#include <qtoolbutton.h>
#include <qiconset.h>
#include "klasse.h"


MeinWidget::MeinWidget (QWidget *parent=0, const char*name = 0)
  : QMainWindow (parent, name)
{
  setCaption ("Fildatenbank");
  
  // ======= Menu ==================
  
  QPopupMenu *datei = new QPopupMenu (this);
  Q_CHECK_PTR (datei);
  // Abreissleiste im "Datei"-Menu
  datei->insertTearOffHandle ();
  datei->insertItem ("&Ende", this, SLOT (ende ()), CTRL+Key_E );

  QPopupMenu *filme = new QPopupMenu (this);
  Q_CHECK_PTR (filme);
  filme->insertItem ("&Neu", this, SLOT (neuerFilm ()), CTRL+Key_N);
  filme->insertSeparator ();
  filme->insertItem ("&Suchen", this, SLOT (suchen ()), CTRL+Key_S);

  menuBar ()->insertItem ("&Datei", datei);
  menuBar ()->insertItem ("&Menu", filme);
  

  // ======= Toobar ================

  QToolBar *toolBar = new QToolBar (this, "some tools");
  QToolButton *bSuch = new QToolButton (QIconSet (), "Suche...", QString::null,
    this, SLOT (suchen ()), toolBar, "suchen");
  setUsesTextLabel (true);
  c = new QCheckBox ("Case Sensitive", toolBar);


  // ======= StatusBar ============
  
  s = new QStatusBar (this);

  // ======= Hauptwidget ===========
  
  table = new QTable (this);
  table->setNumRows (0);
  table->setNumCols (2);
  activeRow = 0;
  setCentralWidget (table);
}


void MeinWidget::ende (void)
{
  switch (
    QMessageBox::question (this, "Anwendung beenden",
      "Nicht gespeicherte Daten gehen verloren.\n\tWirklich Beenden?",
      QMessageBox::Yes, QMessageBox::No))
    {
      case QMessageBox::Yes:
        qApp->quit ();
        break;
      case QMessageBox::No:
        break;
    }
}


void MeinWidget::neuerFilm ()
{
  bool ok;
  QString filmName = QInputDialog::getText ("Filmname", "Bitte Filmnamen eingeben:",
    QLineEdit::Normal, "Stirb ganz langsam", &ok, this);
  if (ok && (!filmName.isEmpty ()))
    {
      int dauer = QInputDialog::getInteger ("Filmdauer", "Bitte Filmdauer/min eingeben:",
        0, 0, 1000, 1, &ok, this);
      if (ok && (dauer > 0))
        {
          table->setNumRows (table->numRows () + 1);
          table->setRowReadOnly (activeRow, TRUE);
          table->setText (activeRow, 0, filmName);
          QString d = QString ("%1 min").arg (dauer);
          table->setText (activeRow, 1, d);
          activeRow++;
          QString msg = QString ("%1 %2 in der Datenbank").arg (activeRow).arg (activeRow>1? "Filme" : "Film");
          s->message (msg);
        }
    }
}

void MeinWidget::suchen ()
{
  bool ok;
  QString suchText = QInputDialog::getText ("Suchen", "Wonach soll gesucht werden:",
    QLineEdit::Normal, QString::null, &ok, this);
  if (ok && (!suchText.isEmpty ()))
    {
      table->clearSelection (false);
      for (int i = 0; i < table->numRows (); i++)
        {
          QString filmTitel = table->text (i, 0);
          if (filmTitel.contains (suchText, c->isChecked ()) > 0)
            table->selectRow (i);
        }
    }
}

int main( int argc, char **argv )
{
    QApplication a( argc, argv );
    MeinWidget *hallo = new MeinWidget;
    a.setMainWidget( hallo );
    hallo->show();
    return a.exec();
}
